<colgroup>{% for column in columns %}
    <col class="{% if column.has_css_class %}{{ column.css_class }} {% endif %}{% if column.is_sorted %}sorted {{ column.sort_direction }}{% endif %}"/>{% endfor %}
</colgroup>
